@@ -127,6 +127,13 @@ void SourcesListTest::initTestCase()
             QString(cwd+"/data/test2.list")
         }
     );
+    sampleSourcesHasDuplicateFiles = QStringList(
+        {
+            QString(cwd+"/data/test1.list"),
+            QString(cwd+"/data/test1.list"),
+            QString(cwd+"/data/test2.list")
+        }
+    );
     
     
     outputFile = QString(cwd+"/data/write_test.list");
@@ -178,6 +185,17 @@ void SourcesListTest::testConstructor()
             + QString::number(shouldntBeEmpty.count())
         )
     );
+    int previousCount = subjectDefaultConstructor.entries().count();
+    subjectDefaultConstructor.reload();
+    QVERIFY2(
+        previousCount == subjectDefaultConstructor.entries().count(),
+        qPrintable(
+            "The default constructor should have given us the same number of entries as the subsequent reload() call. I had "
+            + QString::number(previousCount)
+            + " and now I have "
+            + QString::number(subjectDefaultConstructor.entries().count())
+        )
+    );
     
     QApt::SourcesList subjectParentOnly(&parentObject);
     shouldntBeEmpty = subjectParentOnly.sourceFiles();
@@ -201,6 +219,17 @@ void SourcesListTest::testConstructor()
         shouldntBeEmpty.count() == 2,
         "The list-only constructor should have given us an empty file list, but it didn't."
     );
+
+    QApt::SourcesList subjectDuplicateListOnly(0, sampleSourcesHasDuplicateFiles);
+    shouldntBeEmpty = subjectDuplicateListOnly.sourceFiles();
+    QVERIFY2(
+        subjectDuplicateListOnly.parent() == 0,
+        "The list-only constructor doesn't have a zero parent?!"
+    );
+    QVERIFY2(
+        shouldntBeEmpty.count() == 2,
+        "The list-only constructor should have given us an empty file list, but it didn't."
+    );
     
     QApt::SourcesList subjectParentAndList(&parentObject, sampleSourcesHasTwoFiles);
     shouldntBeEmpty = subjectListOnly.sourceFiles();
@@ -220,8 +249,8 @@ void SourcesListTest::testConstructor()
  * 2. Verify that we loaded the file using entries()
  * 3. Verify that we loaded the file using entries(filename)
  */
-#define SOURCES_COUNT 12
-#define TEST1_MD5     "327eec1a9e826859e478258e75c07fbb"
+#define SOURCES_COUNT 13
+#define TEST1_MD5     "56717306e28a529f89b56c6ee6082375"
 void SourcesListTest::testLoadSourcesOneFile()
 {
     QVERIFY2(sampleSourcesHasOneFile.count() == 1, "Verify we have only one source...");
@@ -400,6 +429,19 @@ void SourcesListTest::testLoadSourcesOneFile()
         false, // <-- Note, disabled!
         true
     );
+    // This line ensures that lines only containing comment characters (e.g. ##)
+    // are discarded as invalid.
+    verifySourceEntry(
+        "Line #12",
+        entries[12],
+        "",
+        "",
+        "",
+        "",
+        "",
+        false, // <-- Note, disabled!
+        false
+    );
 }
 
 #define SOURCES_COUNT_2   3
@@ -569,6 +611,8 @@ void SourcesListTest::testRemoveSource()
     QApt::SourceEntry entryOne;
     QApt::SourceEntry entryTwo;
 
+    subject.reload();
+    
     // Construct our two sources
     entryOne.setType("deb");
     entryOne.setUri("https://foo.com/bar");
@@ -625,10 +669,19 @@ void SourcesListTest::testSaveSources()
     
     subject.addEntry(entryOne);
     
+    qDebug() << "Here's your sources list:\n" << subject.toString();
+    
+    QVERIFY2(
+                subject.containsEntry(entryOne),
+                qPrintable(
+                    "I expected to have the entry "
+                    + entryOne.toString()
+                )
+    );
     QVERIFY2(
         subject.entries().count() == 1,
         qPrintable(
-            "I expected to have 2 sources. I found "
+            "I expected to have 1 sources. I found "
             + QString::number(subject.entries().count())
             + " entries."
         )
@@ -666,6 +719,26 @@ void SourcesListTest::testSaveSources()
             + " entries."
         )
     );
+
+    loadingAfterSecondSave.save();
+    QVERIFY2(
+        loadingAfterSecondSave.entries().count() == 2,
+        qPrintable(
+            "I expected to have 2 sources after adding another. I found "
+            + QString::number(loadingAfterSecondSave.entries().count())
+            + " entries."
+        )
+    );
+
+    QApt::SourcesList loadingAfterSecondSaveB(0, outfilesListJustOne);
+    QVERIFY2(
+        loadingAfterSave.entries().count() == 2,
+        qPrintable(
+            "I expected to have 2 sources after loading again. I found "
+            + QString::number(loadingAfterSecondSaveB.entries().count())
+            + " entries."
+        )
+    );
     
     loadingAfterSecondSave.removeEntry(entryOne);
     loadingAfterSecondSave.removeEntry(entryTwo);
